@@ -8,7 +8,8 @@ function(behavior,phaseX,v,statX){
   tphase<-table(phaseX)
   mlin<- tphase[names(tphase)==v]
   omedian<- abmedian[names(abmedian)==v]
-  
+  stats<-c(statX,round(omedian,3))
+ print(stats)
   l<-locator(1)
   mlin<-l$x+mlin
   if (statX=="mean") {cl="blue"}   
